{% extends "admin/base_site.html" %}
{% block extrastyle %}
<style type="text/css">
.row1:hover, .row2:hover {background-color:#fff9d7;}
</style>
{% endblock %}
{% block branding %}
<h1 id="site-name">Reports</h1>
{% endblock %}